==> gdata_2.8.0.zip: gdata/doc/mapLevels.R <==
###################################################
### chunk number 1: ex01
###################################################
library(gdata)
(fac <- factor(c("B", "A", "Z", "D")))
(map <- mapLevels(x=fac))


###################################################
### chunk number 2: ex02
###################################################
(int <- as.integer(fac))
mapLevels(x=int) <- map
int
identical(fac, int)


###################################################
### chunk number 3: ex03
###################################################
str(map)


###################################################
### chunk number 4: ex04
###################################################
map[[2]] <- as.integer(c(1, 2))
map
int <- as.integer(fac)
mapLevels(x=int) <- map
int


###################################################
### chunk number 5: ex05
###################################################
(f1 <- factor(c("A", "D", "C")))
(f2 <- factor(c("B", "D", "C")))


###################################################
### chunk number 6: ex06
###################################################
fTest <- f1
levels(fTest) <- c("A", "B", "C", "D")
fTest


###################################################
### chunk number 7: ex07
###################################################
fTest <- f1
levels(fTest) <- list(A="A", B="B",
                      C="C", D="D")
fTest


###################################################
### chunk number 8: ex08
###################################################
(bigMap <- mapLevels(x=list(f1, f2),
                     codes=FALSE,
                     combine=TRUE))
mapLevels(f1) <- bigMap
mapLevels(f2) <- bigMap
f1
f2
cbind(as.character(f1), as.integer(f1),
      as.character(f2), as.integer(f2))

==> gdata_2.8.2.zip: gdata/doc/mapLevels.R <==
###################################################
### chunk number 1: ex01
###################################################
#line 53 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/mapLevels.Rnw"
library(gdata)
(fac <- factor(c("B", "A", "Z", "D")))
(map <- mapLevels(x=fac))


###################################################
### chunk number 2: ex02
###################################################
#line 65 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/mapLevels.Rnw"
(int <- as.integer(fac))
mapLevels(x=int) <- map
int
identical(fac, int)


###################################################
### chunk number 3: ex03
###################################################
#line 79 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/mapLevels.Rnw"
str(map)


###################################################
### chunk number 4: ex04
###################################################
#line 89 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/mapLevels.Rnw"
map[[2]] <- as.integer(c(1, 2))
map
int <- as.integer(fac)
mapLevels(x=int) <- map
int


###################################################
### chunk number 5: ex05
###################################################
#line 106 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/mapLevels.Rnw"
(f1 <- factor(c("A", "D", "C")))
(f2 <- factor(c("B", "D", "C")))


###################################################
### chunk number 6: ex06
###################################################
#line 117 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/mapLevels.Rnw"
fTest <- f1
levels(fTest) <- c("A", "B", "C", "D")
fTest


###################################################
### chunk number 7: ex07
###################################################
#line 127 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/mapLevels.Rnw"
fTest <- f1
levels(fTest) <- list(A="A", B="B",
                      C="C", D="D")
fTest


###################################################
### chunk number 8: ex08
###################################################
#line 151 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/mapLevels.Rnw"
(bigMap <- mapLevels(x=list(f1, f2),
                     codes=FALSE,
                     combine=TRUE))
mapLevels(f1) <- bigMap
mapLevels(f2) <- bigMap
f1
f2
cbind(as.character(f1), as.integer(f1),
      as.character(f2), as.integer(f2))
